summaryrefslogtreecommitdiffstats
path: root/kpoker/top.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kpoker/top.cpp')
-rw-r--r--kpoker/top.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kpoker/top.cpp b/kpoker/top.cpp
index 56cf07bb..30365fd1 100644
--- a/kpoker/top.cpp
+++ b/kpoker/top.cpp
@@ -63,7 +63,7 @@ PokerWindow::PokerWindow()
m_kpok->updateLHLabel();
//FIXME: LHLabel is shown twize until the bar is repainted!
- initKAction();
+ initTDEAction();
readOptions();
}
@@ -76,7 +76,7 @@ PokerWindow::~PokerWindow()
// ----------------------------------------------------------------
-void PokerWindow::initKAction()
+void PokerWindow::initTDEAction()
{
//Game
KStdGameAction::gameNew(TQT_TQOBJECT(m_kpok), TQT_SLOT(newGame()), actionCollection());
@@ -87,15 +87,15 @@ void PokerWindow::initKAction()
showMenubarAction =
KStdAction::showMenubar(TQT_TQOBJECT(this), TQT_SLOT(toggleMenubar()), actionCollection());
- soundAction = new KToggleAction(i18n("Soun&d"), 0, TQT_TQOBJECT(m_kpok),
+ soundAction = new TDEToggleAction(i18n("Soun&d"), 0, TQT_TQOBJECT(m_kpok),
TQT_SLOT(toggleSound()), actionCollection(), "options_sound");
if (m_kpok->getSound())
m_kpok->toggleSound();
- blinkingAction = new KToggleAction(i18n("&Blinking Cards"), 0, TQT_TQOBJECT(m_kpok),
+ blinkingAction = new TDEToggleAction(i18n("&Blinking Cards"), 0, TQT_TQOBJECT(m_kpok),
TQT_SLOT(toggleBlinking()), actionCollection(), "options_blinking");
if (m_kpok->getBlinking())
m_kpok->toggleBlinking();
- adjustAction = new KToggleAction(i18n("&Adjust Bet is Default"), 0,
+ adjustAction = new TDEToggleAction(i18n("&Adjust Bet is Default"), 0,
TQT_TQOBJECT(m_kpok), TQT_SLOT(toggleAdjust()), actionCollection(), "options_adjust");
if (m_kpok->getAdjust())
m_kpok->toggleAdjust();
@@ -108,20 +108,20 @@ void PokerWindow::initKAction()
KStdAction::preferences(TQT_TQOBJECT(m_kpok), TQT_SLOT(slotPreferences()), actionCollection());
// Keyboard shortcuts.
- (void)new KAction(i18n("Draw"), KShortcut(TQt::Key_Return), TQT_TQOBJECT(m_kpok),
+ (void)new TDEAction(i18n("Draw"), TDEShortcut(TQt::Key_Return), TQT_TQOBJECT(m_kpok),
TQT_SLOT(drawClick()), actionCollection(), "draw");
- (void)new KAction(i18n("Exchange Card 1"), KShortcut(TQt::Key_1), TQT_TQOBJECT(m_kpok),
+ (void)new TDEAction(i18n("Exchange Card 1"), TDEShortcut(TQt::Key_1), TQT_TQOBJECT(m_kpok),
TQT_SLOT(exchangeCard1()), actionCollection(), "exchange_card_1");
- (void)new KAction(i18n("Exchange Card 2"), KShortcut(TQt::Key_2), TQT_TQOBJECT(m_kpok),
+ (void)new TDEAction(i18n("Exchange Card 2"), TDEShortcut(TQt::Key_2), TQT_TQOBJECT(m_kpok),
TQT_SLOT(exchangeCard2()), actionCollection(), "exchange_card_2");
- (void)new KAction(i18n("Exchange Card 3"), KShortcut(TQt::Key_3), TQT_TQOBJECT(m_kpok),
+ (void)new TDEAction(i18n("Exchange Card 3"), TDEShortcut(TQt::Key_3), TQT_TQOBJECT(m_kpok),
TQT_SLOT(exchangeCard3()), actionCollection(), "exchange_card_3");
- (void)new KAction(i18n("Exchange Card 4"), KShortcut(TQt::Key_4), TQT_TQOBJECT(m_kpok),
+ (void)new TDEAction(i18n("Exchange Card 4"), TDEShortcut(TQt::Key_4), TQT_TQOBJECT(m_kpok),
TQT_SLOT(exchangeCard4()), actionCollection(), "exchange_card_4");
- (void)new KAction(i18n("Exchange Card 5"), KShortcut(TQt::Key_5), TQT_TQOBJECT(m_kpok),
+ (void)new TDEAction(i18n("Exchange Card 5"), TDEShortcut(TQt::Key_5), TQT_TQOBJECT(m_kpok),
TQT_SLOT(exchangeCard5()), actionCollection(), "exchange_card_5");
- setupGUI( KMainWindow::Save | StatusBar | Keys | Create);
+ setupGUI( TDEMainWindow::Save | StatusBar | Keys | Create);
}
@@ -168,7 +168,7 @@ void PokerWindow::toggleStatusbar()
/* Ask the user if he/she wants to save the game. This virtual method
* is called from the Quit KAction (I think).
*/
bool PokerWindow::queryClose()
@@ -168,7 +168,7 @@ void PokerWindow::toggleStatusbar()
/* Ask the user if he/she wants to save the game. This virtual method
- * is called from the Quit KAction (I think).
+ * is called from the Quit TDEAction (I think).
*/
bool PokerWindow::queryClose()